@@ -8,7 +8,8 @@ use warnings;
 use Carp;
 use JSON;
 
-use base qw{ Astro::SpaceTrack };
+use Astro::SpaceTrack;
+my @ISA = qw{ Astro::SpaceTrack };
 
 eval {
     local @INC = @INC;
@@ -18,7 +19,7 @@ eval {
     1;
 } or croak 'Can not load Mock::LWP::UserAgent. Code must be run from the base directory of the Astro-SpaceTrack distribution';
 
-our $VERSION = '0.094_01';
+our $VERSION = '0.095_01';
 
 {
     my $json;
@@ -246,7 +247,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2016 by Thomas R. Wyant, III
+Copyright (C) 2014-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
